@@ -25,8 +25,6 @@ from driftpy.math.positions import (
 )
 
 from driftpy.constants.numeric_constants import (
-    MAX_LEVERAGE,
-    PARTIAL_LIQUIDATION_RATIO,
     AMM_RESERVE_PRECISION,
 )
 
@@ -92,7 +90,7 @@ class ClearingHouseUser:
         )
 
     async def get_unrealised_pnl(self, market_index: int=None):
-        assert(market_index is None or str(market_index).isdigit())
+        assert(market_index is None or int(market_index))
         positions_account = await self.get_user_positions_account()
 
         pnl = 0
@@ -106,6 +104,10 @@ class ClearingHouseUser:
 
         return pnl
 
+    async def get_collateral(self):
+        collateral = (await self.clearing_house.get_user_account()).collateral
+        return collateral
+
     async def get_total_collateral(self):
         collateral = (await self.clearing_house.get_user_account()).collateral
         return collateral + await self.get_unrealised_pnl()
@@ -122,7 +124,7 @@ class ClearingHouseUser:
         return value
 
     async def get_position_value(self, market_index: int=None):
-        assert(market_index is None or str(market_index).isdigit())
+        assert(market_index is None or int(market_index))
         positions_account = await self.get_user_positions_account()
         value = 0
         for position in positions_account.positions:
@@ -144,11 +146,33 @@ class ClearingHouseUser:
 
     async def get_free_collateral(self):
         return (await self.get_total_collateral()) - (
-            (await self.get_total_position_value()) / MAX_LEVERAGE
+            (await self.get_margin_requirement('initial')) 
         )
 
+    async def get_margin_requirement(self, kind):
+        assert(kind in ['initial','partial', 'maintenance'])
+        
+        positions_account = await self.get_user_positions_account()
+        value = 0
+        for position in positions_account.positions:
+            if position.base_asset_amount!=0:
+                market = await self.clearing_house.get_market(
+                    position.market_index
+                )  # todo repeat querying
+
+                mr = None
+                if kind == 'partial':
+                    mr = market.margin_ratio_partial
+                elif kind == 'initial':
+                    mr = market.margin_ratio_initial
+                else:
+                    mr = market.margin_ratio_maintenance
+
+                value += (calculate_base_asset_value(market, position) *  (mr / 10000))
+        return value
+
     async def can_be_liquidated(self):
-        return (await self.get_margin_ratio()) <= PARTIAL_LIQUIDATION_RATIO / 100
+        return (await self.get_total_collateral() <= await self.get_margin_requirement('partial'))
 
     async def liquidation_price(self, market_index: int):
         # todo
